from subprocess import run

def command_cmd(command_,arguments):
        #TODO: deberia verificar que si el sistema es windows.
        if (arguments):
            return run(f'{command_}',arguments,shell=True) 
        return run(f'{command_}',shell=True)


if __name__ == "__main__":
    from command_cmd import command_cmd
else:
    from .command_cmd import command_cmd
from pathlib import PurePath

def mkdir(destination = False,arguments = False,options={
    "debug": False
}):
    if (options["debug"]):
        print(destination,arguments)
    if (destination):
        destination = PurePath(destination)
        return command_cmd(f'mkdir "{destination}"',arguments)
    return False
